@@ -104,9 +104,9 @@ def run_worker(args):
 
     worker = Worker(queues, heart_beat=args.heartbeat)
     if (channels is None) or len(channels) == 0:
-      print(f"**Started worker with heart beat of {args.heartbeat} second(s)")
+      print(f"**Started worker with heart beat of {args.heartbeat} second(s)", flush=True)
     else:
-      print(f"**Started worker to monitor channels", channels, f"with heart beat of {args.heartbeat} second(s)")
+      print(f"**Started worker to monitor channels", channels, f"with heart beat of {args.heartbeat} second(s)", flush=True)
 
     worker.start()
   else:
